@@ -671,6 +671,8 @@ class BaseFrameContainer extends Core
 			// Joomla!v1.5用の設定
 			define('JPATH_BASE', dirname(__FILE__));
 			define('JPATH_SITE', $this->gEnv->getSystemRootPath());
+			define('JPATH_PLUGINS', $gEnvManager->getJoomlaRootPath() . '/class/plugins');			// プラグインパス
+//			define('JPATH_THEMES', $gEnvManager->getTemplatesPath());								// テンプレートパス		## テンプレート内でエラーが発生するのでここでは定義しない(2015/10/13)
 			define('DS', DIRECTORY_SEPARATOR);
 			$this->language = $this->gEnv->getCurrentLanguage();
 			$this->template = $curTemplate;
@@ -684,9 +686,9 @@ class BaseFrameContainer extends Core
 				// JRequest経由でレンダー側にサブテンプレートIDを渡す
 				if (!empty($subTemplateId)) JRequest::injectSetVar('file_template_name', $subTemplateId);
 
-				// サブテンプレートIDの渡し方は以下の方法もある
+				// サブテンプレートIDの渡し方は以下の方法もある(Themlerテンプレート1.39以降はこちらが有効)
 				// サブテンプレートIDを埋め込む
-//				if (!empty($subTemplateId)) $this->setBuffer('<!--TEMPLATE ' . $subTemplateId . ' /-->', 'component');
+				if (!empty($subTemplateId)) $this->setBuffer('<!--TEMPLATE ' . $subTemplateId . ' /-->', 'component');
 			}
 			
 			// 現在のJoomla!ドキュメントを設定
