@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_banner3ImageWidgetContainer.php 5868 2013-03-28 04:08:49Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getWidgetContainerPath('banner3') . '/admin_banner3BaseWidgetContainer.php');
@@ -19,22 +19,22 @@ require_once($gEnvManager->getCommonPath() . '/valueCheck.php');
 class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 {
 	private $serialNo;		// 選択中の項目のシリアル番号
-	private $serialArray = array();		// 表示されている画像リンクシリアル番号
-	private $idArray = array();			// 表示されている画像リンクID
+	private $serialArray = array();		// 表示されている画像シリアル番号
+	private $idArray = array();			// 表示されている画像ID
 	private $isExistsContent;		// コンテンツ項目が存在するかどうか
 	private $itemTypeArray;		// バナー項目のすべての種類
 	private $targetTypeArray;		// リンクターゲットのすべての種類
-	private $itemId;			// 選択中の画像リンク項目
+	private $itemId;			// 選択中の画像項目
 	private $itemType;			// バナー項目の種類
 	private $targetType;			// リンクターゲットの種類
-	private $selectedItems;		// 画像リンク選択用
+	private $selectedItems;		// 画像選択用
 	private $task;				// 処理タスク
-	const IMAGE_LIST_COUNT = 10;		// 表示画像リンク数
+	const IMAGE_LIST_COUNT = 10;		// 表示画像数
+	const LINK_PAGE_COUNT		= 20;			// リンクページ数
 	const IMAGE_ICON_FILE = '/images/system/image16.png';			// イメージアイコン
 	const FLASH_ICON_FILE = '/images/system/flash16.png';		// Flashアイコン
 	const ICON_SIZE = 16;		// アイコンのサイズ
 	const MAX_URL_LENGTH = 30;		// 一覧のURLの最大長
-	const MAX_NOTE_LENGTH = 30;		// 一覧のコメントの最大長
 	const CHANGE_IMAGE_TAG_ID = 'changeimage';			// 画像変更ボタンタグID
 	const CHANGE_URL_TAG_ID = 'changeurl';			// URL変更ボタンタグID
 	const CHANGE_URL_S_TAG_ID = 'changeurl_s';			// URL変更ボタンタグID(スマートフォン用)
@@ -92,7 +92,7 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 		}
 	}
 	/**
-	 * 画像リンク一覧画面作成
+	 * 画像一覧画面作成
 	 *
 	 * @param RequestManager $request		HTTPリクエスト処理クラス
 	 * @param								なし
@@ -110,7 +110,7 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 		
 		// ##### 検索条件 #####
 		$pageNo = $request->trimIntValueOf(M3_REQUEST_PARAM_PAGE_NO, '1');				// ページ番号
-		$maxListCount = self::IMAGE_LIST_COUNT;		// 表示画像リンク数
+		$maxListCount = self::IMAGE_LIST_COUNT;		// 表示画像数
 		
 		// 画像選択画面で使用
 		$this->selectedItems = explode(',', $request->trimValueOf('items'));
@@ -140,29 +140,18 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 		// 総数を取得
 		$totalCount = self::$_mainDb->getImageCount();
 
-		// 表示するページ番号の修正
-		$pageCount = (int)(($totalCount -1) / $maxListCount) + 1;		// 総ページ数
-		if ($pageNo < 1) $pageNo = 1;
-		if ($pageNo > $pageCount) $pageNo = $pageCount;
-		$this->firstNo = ($pageNo -1) * $maxListCount + 1;		// 先頭番号
+		// ページング計算
+		$this->calcPageLink($pageNo, $totalCount, $maxListCount);
 		
-		// #### 画像リンクリストを作成 ####
+		// #### 画像リストを作成 ####
 		self::$_mainDb->getImageList($maxListCount, $pageNo, array($this, 'imageListLoop'));
 		$this->setListTemplateVisibility('itemlist');	// 一覧部の表示制御
 		//if (!$this->isExistsContent) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');// 項目がないときは、一覧を表示しない
 		
-		// ページング用リンク作成
-		$pageLink = '';
-		if ($pageCount > 1){	// ページが2ページ以上のときリンクを作成
-			for ($i = 1; $i <= $pageCount; $i++){
-				if ($i == $pageNo){
-					$link = '&nbsp;' . $i;
-				} else {
-					$link = '&nbsp;<a href="#" onclick="selpage(\'' . $i . '\');return false;">' . $i . '</a>';
-				}
-				$pageLink .= $link;
-			}
-		}
+		// ページングリンク作成
+		$currentBaseUrl = '';		// POST用のリンク作成
+		$pageLink = $this->createPageLink($pageNo, self::LINK_PAGE_COUNT, $currentBaseUrl, 'selpage($1);return false;');
+		
 		// 非表示項目を設定
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		$this->tmpl->addVar("_widget", "id_list", implode($this->idArray, ','));// 表示項目のIDを設定
@@ -171,19 +160,8 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "task", $this->task);	// 処理タスク
 		
 		// ボタンの表示制御
-		if ($this->task == 'image_select'){		// 画像リンク選択タスクのとき
-			$this->tmpl->setAttribute('select_button', 'visibility', 'visible');// 「確定」ボタン
-			
-			// 選択中の画像リンク
-			$itemsStr = $this->convertToDispString(implode($this->selectedItems, ','));
-			$this->tmpl->addVar("_widget", "items", $itemsStr);	// 画像リンク選択項目
-			$this->tmpl->addVar("select_button", "items_label", $itemsStr);	// 画像リンク選択項目
-		} else {
-			$this->tmpl->setAttribute('edit_button', 'visibility', 'visible');// 「新規」「削除」「編集」ボタン
-			
-			// ヘルプの追加
-			$this->convertHelp('edit_button');
-		}
+		$this->tmpl->setAttribute('edit_button', 'visibility', 'visible');// 「新規」「削除」「編集」ボタン
+
 		// ページ定義IDとページ定義のレコードシリアル番号を更新
 		$this->endPageDefParam($defSerial, $defConfigId, $this->paramObj);
 	}
@@ -207,7 +185,7 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 		$act = $request->trimValueOf('act');
 		
 		$this->serialNo = $request->trimValueOf('serial');		// 選択項目のシリアル番号
-		$this->itemId = $request->trimValueOf('item_imageid');		// 選択中の画像リンク項目ID
+		$this->itemId = $request->trimValueOf('item_imageid');		// 選択中の画像項目ID
 		$name = $request->trimValueOf('item_name');
 		$this->itemType = $request->trimValueOf('item_type');
 		$this->targetType = $request->trimValueOf('item_target_type');			// リンクターゲットの種類
@@ -308,7 +286,7 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 					$this->setAppErrorMsg('データ削除に失敗しました');
 				}
 			}
-		} else if ($act == 'select'){		// 画像リンクIDの選択の場合
+		} else if ($act == 'select'){		// 画像IDの選択の場合
 			if (empty($this->itemId)){
 				$this->serialNo = 0;
 				
@@ -461,7 +439,7 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 		if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
 		} else {
-			$this->tmpl->addVar("_widget", "id", $this->itemId);			// 画像リンク項目ID
+			$this->tmpl->addVar("_widget", "id", $this->itemId);			// 画像項目ID
 			$this->tmpl->setAttribute('del_button', 'visibility', 'visible');// 「削除」ボタン
 		}
 		
@@ -482,6 +460,12 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 	function imageListLoop($index, $fetchedRow, $param)
 	{
 		$serial = $this->convertToDispString($fetchedRow['bi_serial']);
+		$id = $fetchedRow['bi_id'];
+		$name = $fetchedRow['bi_name'];
+		$type = $fetchedRow['bi_type'];
+		$width = $fetchedRow['bi_image_width'];
+		$height = $fetchedRow['bi_image_height'];
+		
 		$visible = '';
 		if ($fetchedRow['bi_visible']){	// 項目の表示
 			$visible = 'checked';
@@ -493,7 +477,7 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 		// 閲覧数取得
 		$viewCount = self::$_mainDb->getTotalViewCount($serial);
 		
-		// 項目タイプの設定
+/*		// 項目タイプの設定
 		$iconUrl = '';
 		switch ($fetchedRow['bi_type']){
 			case 0:		// 画像ファイル
@@ -507,47 +491,43 @@ class admin_banner3ImageWidgetContainer extends admin_banner3BaseWidgetContainer
 			default:
 				break;
 		}
-		$iconTag = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
-	
+		$iconTag = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';*/
+		
 		// 画像URL
 		$url = $fetchedRow['bi_image_url'];
 		if (!empty($url)) $url = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $url);
 		
-		// リンク先、備考
-		$redirectUrl = default_bannerCommonDef::getLinkUrlByDevice($fetchedRow['bi_link_url']);
-		$linkUrl = makeTruncStr($redirectUrl, self::MAX_URL_LENGTH);
-		$note = makeTruncStr($fetchedRow['bi_admin_note'], self::MAX_NOTE_LENGTH);
+		// リンク先
+		$linkUrl = default_bannerCommonDef::getLinkUrlByDevice($fetchedRow['bi_link_url']);
+		$linkUrlShort = makeTruncStr($linkUrl, self::MAX_URL_LENGTH);
 	
-		// 画像リンク選択タスクのときは、選択中の項目にチェックをつける
-		$checked = '';
-		if ($this->task == 'image_select'){		// 画像リンク選択タスクのとき
-			if (in_array($fetchedRow['bi_id'], $this->selectedItems)) $checked = 'checked';
-		}
+		// 画像プレビュー用ボタンを作成
+		$eventAttr = 'onclick="showPreview(\''. $id . '\', \'' . $name . '\', \'' . $type . '\', \'' . $this->getUrl($url) . '\', \'' . $width .'\', \'' . $height . '\', \'' . $linkUrl . '\');"';
+		$previewButtonTag = $this->gDesign->createPreviewImageButton(''/*同画面*/, 'プレビュー', ''/*タグID*/, $eventAttr/*クリックイベント時処理*/);
+
 		$row = array(
 			'index' => $index,													// 項目番号
 			'serial' => $serial,								// シリアル番号
-			'id' => $this->convertToDispString($fetchedRow['bi_id']),			// ID
-			'checked' => $checked,				// 項目のチェック状況
-			'type_icon' => $iconTag,					// バナー項目タイプ
-			'type' => $this->convertToDispString($fetchedRow['bi_type']),					// バナー項目タイプ
-			'name' => $this->convertToDispString($fetchedRow['bi_name']),		// 名前
+			'id' => $this->convertToDispString($id),			// ID
+//			'type_icon' => $iconTag,					// バナー項目タイプ
+//			'type' => $this->convertToDispString($type),					// バナー項目タイプ
+			'name' => $this->convertToDispString($name),		// 名前
 			'filename' => $filename,
-			'url' => $this->getUrl($url),					// URL
+//			'url' => $this->getUrl($url),					// URL
 			'link_url' => $this->convertToDispString($linkUrl),					// リンク先URL
-			'width' => $this->convertToDispString($fetchedRow['bi_image_width']),					// 画像幅
-			'height' => $this->convertToDispString($fetchedRow['bi_image_height']),					// 画像高さ
+			'link_url_short' => $this->convertToDispString($linkUrlShort),					// リンク先URL
+			'width' => $this->convertToDispString($width),					// 画像幅
+			'height' => $this->convertToDispString($height),					// 画像高さ
 			'view_count' => $viewCount,								// 閲覧数
 			'visible' => $visible,											// 項目の表示
-			'note' => $this->convertToDispString($note),					// 備考
-			'update_user' => $this->convertToDispString($fetchedRow['lu_name']),	// 更新者
-			'update_dt' => $this->convertToDispDateTime($fetchedRow['bi_create_dt'])	// 更新日時
+			'preview_image_button'	=> $previewButtonTag					// 画像プレビューボタン
 		);
 		$this->tmpl->addVars('itemlist', $row);
 		$this->tmpl->parseTemplate('itemlist', 'a');
 		
 		// 表示中項目のシリアル番号を保存
 		$this->serialArray[] = $fetchedRow['bi_serial'];
-		$this->idArray[] = $fetchedRow['bi_id'];
+		$this->idArray[] = $id;
 		$this->isExistsContent = true;		// コンテンツ項目が存在するかどうか
 		return true;
 	}
