@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: showrss.inc.php 1138 2008-10-27 04:19:28Z fishbone $
+ * @version    SVN: $Id: showrss.inc.php 3474 2010-08-13 10:36:48Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C):
@@ -244,8 +244,8 @@ class ShowRSS_XML
 
 		// Parsing
 		$xml_parser = xml_parser_create($this->encoding);
-		xml_set_element_handler($xml_parser, array(& $this, 'start_element'), array(& $this, 'end_element'));
-		xml_set_character_data_handler($xml_parser, array(& $this, 'character_data'));
+		xml_set_element_handler($xml_parser, array($this, 'start_element'), array($this, 'end_element'));
+		xml_set_character_data_handler($xml_parser, array($this, 'character_data'));
 		if (! xml_parse($xml_parser, $buf, 1)) {
 			return(sprintf('XML error: %s at line %d in %s',
 				xml_error_string(xml_get_error_code($xml_parser)),
@@ -282,7 +282,7 @@ class ShowRSS_XML
 	{
 		if (! $this->is_item || $name != 'ITEM') return;
 
-		$item = array_map(array(& $this, 'escape'), $this->item);
+		$item = array_map(array($this, 'escape'), $this->item);
 		$this->item = array();
 
 		if (isset($item['DC:DATE'])) {
